### Encoding: UTF-8

### Name: adipart
### Title: Additive Diversity Partitioning and Hierarchical Null Model
###   Testing
### Aliases: adipart print.adipart hiersimu print.hiersimu
### Keywords: multivariate

### ** Examples

data(mite)
data(mite.xy)
data(mite.env)
## Function to get equal area partitions of the mite data
cutter <- function (x, cut = seq(0, 10, by = 2.5)) {
    out <- rep(1, length(x))
    for (i in 2:(length(cut) - 1))
        out[which(x > cut[i] & x <= cut[(i + 1)])] <- i
    return(as.factor(out))}
## The hierarchy of sample aggregation
levsm <- data.frame(
    l1=as.factor(1:nrow(mite)),
    l2=cutter(mite.xy$y, cut = seq(0, 10, by = 2.5)),
    l3=cutter(mite.xy$y, cut = seq(0, 10, by = 5)),
    l4=cutter(mite.xy$y, cut = seq(0, 10, by = 10)))
## Let's see in a map
par(mfrow=c(1,3))
plot(mite.xy, main="l1", col=as.numeric(levsm$l1)+1)
plot(mite.xy, main="l2", col=as.numeric(levsm$l2)+1)
plot(mite.xy, main="l3", col=as.numeric(levsm$l3)+1)
par(mfrow=c(1,1))
## Additive diversity partitioning
adipart(mite ~., levsm, index="richness", nsimul=20)
## Hierarchical null model testing
## diversity analysis (similar to adipart)
hiersimu(mite ~., levsm, diversity, relative=TRUE, nsimul=25)
## Hierarchical testing with the Morisita index
morfun <- function(x) dispindmorisita(x)$imst
hiersimu(mite ~., levsm, morfun, drop.highest=TRUE, nsimul=25)



